@@ -1,3 +1,4 @@
+"""Module containing the application class"""
 from typing import Optional
 from typing import Sequence
 
@@ -9,10 +10,21 @@ from checkstyle.utils.store import get_checkstyle_cache_dir
 
 
 class Application:
+    """Application class"""
+
     def __init__(self) -> None:
         self._parser = Parser()
 
     def run(self, argv: Optional[Sequence[str]]) -> int:
+        """Run application
+
+            Args:
+                argv: Arguments vector
+
+            Returns:
+                int: Exit code
+
+        """
         args_dict = self._parser.parse_args_dict(argv)
 
         version = args_dict.pop('runtime_version')
@@ -24,7 +36,7 @@ class Application:
 
         exit_code = run_command(
             filename=filename,
-            cache_dir=get_checkstyle_cache_dir(),
+            base_dir=get_checkstyle_cache_dir(),
             args=convert_args_dict_to_list(args_dict) + files,
         )
         return exit_code
